@@ -4,6 +4,7 @@ from .Button import Button
 from .Chart import Chart
 from .CheckBox import CheckBox
 from .CircularGauge import CircularGauge
+from .DDDataGrid import DDDataGrid
 from .DataGrid import DataGrid
 from .DateBox import DateBox
 from .Drawer import Drawer
@@ -44,6 +45,7 @@ __all__ = [
     "Chart",
     "CheckBox",
     "CircularGauge",
+    "DDDataGrid",
     "DataGrid",
     "DateBox",
     "Drawer",
